@@ -1,16 +1,16 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2021 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2021-2022 -- leonerd@leonerd.org.uk
 
 use v5.26;
 
-use Object::Pad;
+use Object::Pad 0.66;
 
-package App::sdview::Output 0.07;
+package App::sdview::Output 0.08;
 role App::sdview::Output;
 
-has $_content;
+field $_content;
 
 method say ( @s ) { $_content .= join "", @s, "\n"; }
 
